@@ -1,11 +1,8 @@
 package Event::RPC;
 
-$VERSION  = "1.08_01";
+$VERSION  = "1.03";
 $PROTOCOL = "1.00";
 
-use strict;
-use utf8;
-
 sub crypt {
     my $class = shift;
     my ($user, $pass) = @_;
@@ -14,8 +11,6 @@ sub crypt {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Event::RPC - Event based transparent Client/Server RPC framework
@@ -76,26 +71,13 @@ If you like to use SSL encryption you need to install
 
   IO::Socket::SSL
 
-Event::RPC needs minimum one of the following modules for
-data serialisation:
+As well Event::RPC makes heavy use of the
 
-  Sereal (::Decoder and ::Encoder)
-  CBOR::XS
-  JSON::XS
   Storable
 
-Server and client negotiate automatically which serialiser to use
-to achieve maximum compatibility.
-
-Some words about the Storable module: it's known to be insecure,
-so Event::RPC uses it as the last option. You can even prevent
-Event::RPC from using it at all (even when it's installed, which
-is the case for nearly every Perl installation) - check manpages
-of Event::Server and Event::Client about the details.
-
-In case you use Storable take care that both client and server
-use B<exactly the same version of the Storable module>!
-Otherwise Event::RPC client/server communication will fail badly.
+module, which is part of the Perl standard library. It's important
+that both client and server use B<exactly the same version of the Storable
+module>! Otherwise Event::RPC client/server communication will fail badly.
 
 =head1 INSTALLATION
 
@@ -181,11 +163,11 @@ They must be passed as a direkt argument of the method subroutine.
 
 =head1 AUTHORS
 
-  Jörn Reder <joern AT zyn.de>
+  Jrn Reder <joern at zyn dot de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
