@@ -1,16 +1,8 @@
 package Event::RPC::Connection;
 
 use strict;
-use utf8;
-
 use Carp;
 
-use Event::RPC::Message::Negotiate;
-
-#-- This can be changed for testing purposes e.g. to simulate
-#-- old servers which don't perform any format negotitation.
-$Event::RPC::Server::DEFAULT_MESSAGE_FORMAT = "Event::RPC::Message::Negotiate";
-
 my $CONNECTION_ID;
 
 sub get_cid                     { shift->{cid}                          }
@@ -22,16 +14,12 @@ sub get_loaded_classes          { shift->{server}->{loaded_classes}     }
 sub get_objects                 { shift->{server}->{objects}            }
 sub get_client_oids             { shift->{client_oids}                  }
 
-sub get_message_format          { shift->{message_format}               }
 sub get_watcher                 { shift->{watcher}                      }
-sub get_write_watcher           { shift->{write_watcher}                }
 sub get_message                 { shift->{message}                      }
 sub get_is_authenticated        { shift->{is_authenticated}             }
 sub get_auth_user               { shift->{auth_user}                    }
 
-sub set_message_format          { shift->{message_format}       = $_[1] }
 sub set_watcher                 { shift->{watcher}              = $_[1] }
-sub set_write_watcher           { shift->{write_watcher}        = $_[1] }
 sub set_message                 { shift->{message}              = $_[1] }
 sub set_is_authenticated        { shift->{is_authenticated}     = $_[1] }
 sub set_auth_user               { shift->{auth_user}            = $_[1] }
@@ -49,10 +37,8 @@ sub new {
         is_authenticated        => (!$server->get_auth_required),
         auth_user               => "",
         watcher                 => undef,
-        write_watcher           => undef,
         message                 => undef,
         client_oids             => {},
-        message_format          => $Event::RPC::Server::DEFAULT_MESSAGE_FORMAT,
     }, $class;
 
     if ( $sock ) {
@@ -77,10 +63,7 @@ sub disconnect {
     my $self = shift;
 
     $self->get_server->get_loop->del_io_watcher($self->get_watcher);
-    $self->get_server->get_loop->del_io_watcher($self->get_write_watcher)
-        if $self->get_write_watcher;
     $self->set_watcher(undef);
-    $self->set_write_watcher(undef);
     close $self->get_sock;
 
     my $server = $self->get_server;
@@ -133,7 +116,7 @@ sub input {
     my $message = $self->get_message;
 
     if ( not $message ) {
-        $message = $self->get_message_format->new ($self->get_sock);
+        $message = Event::RPC::Message->new ($self->get_sock);
         $self->set_message($message);
     }
 
@@ -162,22 +145,7 @@ sub input {
             msg => "Unexpected error on incoming RPC call: $@",
         };
     }
-    elsif ( $cmd eq 'neg_formats_avail') {
-        $rc = {
-            ok       => 1,
-            msg      => join(",", @{$self->get_server->get_message_formats})
-        };
-    }
-    elsif ( $cmd eq 'neg_format_set') {
-        $rc = $self->client_requests_message_format($request->{msg});
-    }
     elsif ( $cmd eq 'version' ) {
-        #-- Probably we have fallen back to Storable because an old
-        #-- client has connected. so we change the negotiation
-        #-- message handler to the fallback handler for further
-        #-- communication on this connection.
-        $self->set_message_format(ref $message);
-
         $rc = {
             ok       => 1,
             version  => $Event::RPC::VERSION,
@@ -221,48 +189,22 @@ sub input {
 
     $server->set_active_connection(undef);
 
-    $message->set_data($rc);
+    $message->write($rc) and return;
 
-    my $watcher = $self->get_server->get_loop->add_io_watcher (
+    my $watcher;
+    $watcher = $self->get_server->get_loop->add_io_watcher (
         fh      => $self->get_sock,
         poll    => 'w',
         cb      => sub {
-            if ( $message->write ) {
-                $self->get_server->get_loop->del_io_watcher($self->get_write_watcher)
-                    if $self->get_write_watcher;
-                $self->set_write_watcher();
-            }
+            $self->get_server->get_loop->del_io_watcher($watcher)
+                if $message->write;
             1;
         },
     );
 
-    $self->set_write_watcher($watcher);
-
     1;
 }
 
-sub client_requests_message_format {
-    my $self = shift;
-    my ($client_format) = @_;
-
-    foreach my $format ( @{$self->get_server->get_message_formats} ) {
-        if ( $client_format eq $format ) {
-            $self->set_message_format(
-                Event::RPC::Message::Negotiate->known_message_formats
-                                              ->{$client_format}
-            );
-
-            eval "use ".$self->get_message_format;
-            return { ok => 0, msg => "Server rejected format '$client_format': $@" }
-                if $@;
-
-            return { ok => 1 };
-        }
-    }
-
-    return { ok => 0, msg => "Server rejected format '$client_format'" };
-}
-
 sub authorize_user {
     my $self = shift;
     my ($request) = @_;
@@ -318,15 +260,15 @@ sub create_new_object {
 
     }
 
-    # ok, load class and execute the method
+    # load the class if not done yet
+    $self->load_class($class) if $self->get_server->get_load_modules;
+
+    # resolve object params
+    $self->resolve_object_params ($request->{params});
+
+    # ok, the class is there, let's execute the method
     my $object = eval {
-        # load the class if not done yet
-        $self->load_class($class) if $self->get_server->get_load_modules;
-
-        # resolve object params
-        $self->resolve_object_params ($request->{params});
-
-        $class->$class_method (@{$request->{params}})
+            $class->$class_method (@{$request->{params}})
     };
 
     # report error
@@ -377,7 +319,7 @@ sub load_class {
                         if -f "$dir/$rel_filename";
             }
 
-            croak "File for class '$class' not found\n"
+            croak "File for class '$class' not found"
                 if not $filename;
 
             $load_class_info->{filename} = $filename;
@@ -387,14 +329,18 @@ sub load_class {
         $mtime ||= 0;
 
         $self->log (3, "Class '$class' ($load_class_info->{filename}) changed on disk. Reloading...")
-            if $mtime > $load_class_info->{mtime};
+                if $mtime > $load_class_info->{mtime};
 
         do $load_class_info->{filename};
 
         if ( $@ ) {
             $self->log ("Can't load class '$class': $@");
             $load_class_info->{mtime} = 0;
-            die "Can't load class $class: $@";
+
+            return {
+                ok  => 0,
+                msg => "Can't load class $class: $@",
+            };
         }
         else {
             $self->log (3, "Class '$class' successfully loaded");
@@ -420,7 +366,7 @@ sub execute_object_method {
     my $method = $request->{method};
 
     if ( not defined $object_entry ) {
-        # object does not exist
+        # object does not exists
         $self->log ("Illegal access to unknown object with oid=$oid");
         return {
             ok  => 0,
@@ -442,15 +388,14 @@ sub execute_object_method {
 
     my $return_type = $self->get_classes->{$class}->{$method};
 
-    # ok, try loading class and executing the method
+    # (re)load the class if not done yet
+    $self->load_class($class) if $self->get_server->get_load_modules;
+
+    # resolve object params
+    $self->resolve_object_params ($request->{params});
+
+    # ok, try executing the method
     my @rc = eval {
-        # (re)load the class if not done yet
-        $self->load_class($class) if $self->get_server->get_load_modules;
-
-        # resolve object params
-        $self->resolve_object_params ($request->{params});
-
-        # exeute method
         $object_entry->{object}->$method (@{$request->{params}})
     };
 
@@ -605,8 +550,6 @@ sub resolve_object_params {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Event::RPC::Connection - Represents a RPC connection
@@ -678,11 +621,11 @@ no need to mess with that.
 
 =head1 AUTHORS
 
-  Jörn Reder <joern AT zyn.de>
+  Jrn Reder <joern at zyn dot de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
