@@ -1,5 +1,7 @@
+# $Id: Message.pm,v 1.7 2009-04-22 10:53:51 joern Exp $
+
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -10,28 +12,9 @@ package Event::RPC::Message;
 
 use Carp;
 use strict;
-use utf8;
-
-my %DECODERS = (
-    STOR    => sub { require Storable; Storable::thaw($_[0])                    },
-    JSON    => sub { require JSON::XS; JSON::XS->new->allow_tags->decode($_[0]) },
-    CBOR    => sub { require CBOR::XS; CBOR::XS->new->decode($_[0])             },
-    SERL    => sub { require Sereal;   Sereal::decode_sereal($_[0])             },
-
-    TEST    => sub { require Storable; Storable::thaw($_[0])                    },
-);
-
-my %ENCODERS = (
-    STOR    => sub { require Storable; Storable::nfreeze ($_[0])                                                    },
-    JSON    => sub { require JSON::XS; '%E:R:JSON%'.JSON::XS->new->latin1->allow_blessed->allow_tags->encode($_[0]) },
-    CBOR    => sub { require CBOR::XS; '%E:R:CBOR%'.CBOR::XS->new->encode($_[0])                                    },
-    SERL    => sub { require Sereal;   '%E:R:SERL%'.Sereal::encode_sereal($_[0])                                    },
-
-    TEST    => sub { "//NEGOTIATE(A,B,C)//" },
-);
+use Storable;
 
 my $DEBUG = 0;
-my $MAX_PACKET_SIZE = 2*1024*1024*1024;
 
 sub get_sock                    { shift->{sock}                         }
 
@@ -43,20 +26,12 @@ sub set_buffer                  { shift->{buffer}               = $_[1] }
 sub set_length                  { shift->{length}               = $_[1] }
 sub set_written                 { shift->{written}              = $_[1] }
 
-sub get_max_packet_size {
-    return $MAX_PACKET_SIZE;
-}
-
-sub set_max_packet_size {
-    my $class = shift;
-    my ($value) = @_;
-    $MAX_PACKET_SIZE = $value;
-}
-
 sub new {
     my $class = shift;
     my ($sock) = @_;
 
+    $sock->blocking(1);
+
     my $self = bless {
         sock    => $sock,
         buffer  => undef,
@@ -69,10 +44,7 @@ sub new {
 
 sub read {
     my $self = shift;
-    my ($blocking) = @_;
 
-    $self->get_sock->blocking($blocking?1:0);
-    
     if ( not defined $self->{buffer} ) {
         my $length_packed;
         $DEBUG && print "DEBUG: going to read header...\n";
@@ -81,8 +53,8 @@ sub read {
         die "DISCONNECTED" if !(defined $rc) || $rc == 0;
         $self->{length} = unpack("N", $length_packed);
         $DEBUG && print "DEBUG: packet size=$self->{length}\n";
-        die "Incoming message size exceeds limit of $MAX_PACKET_SIZE bytes"
-                if $self->{length} > $MAX_PACKET_SIZE;
+        die "Incoming message too big"
+                if $self->{length} > 4194304;
     }
 
     my $buffer_length = length($self->{buffer}||'');
@@ -110,7 +82,7 @@ sub read {
 
     $DEBUG && print "DEBUG: read finished, length=$buffer_length\n";
 
-    my $data = $self->decode_message($self->{buffer});
+    my $data = Storable::thaw($self->{buffer});
 
     $self->{buffer} = undef;
     $self->{length} = 0;
@@ -122,38 +94,24 @@ sub read_blocked {
     my $self = shift;
 
     my $rc;
-    $rc = $self->read(1) while not defined $rc;
+    $rc = $self->read while not defined $rc;
 
     return $rc;
 }
 
-sub set_data {
+sub write {
     my $self = shift;
     my ($data) = @_;
 
-    $DEBUG && print "DEBUG: Message->set_data($data)\n";
+    $DEBUG && print "DEBUG: going to write...\n";
 
-    my $packed = $self->encode_message($data);
-
-    if ( length($packed) > $MAX_PACKET_SIZE ) {
-        Event::RPC::Server->instance->log("ERROR: response packet exceeds limit of $MAX_PACKET_SIZE bytes");
-        $data = { rc => 0, msg => "Response packed exceeds limit of $MAX_PACKET_SIZE bytes" };
-        $packed = $self->encode_message($data);
+    if ( not defined $self->{buffer} ) {
+        my $packed = Storable::nfreeze ($data);
+        $self->{buffer} = pack("N", length($packed)).$packed;
+        $self->{length} = length($self->{buffer});
+        $self->{written} = 0;
     }
 
-    $self->{buffer} = pack("N", length($packed)).$packed;
-    $self->{length} = length($self->{buffer});
-    $self->{written} = 0;
-
-    1;
-}
-
-sub write {
-    my $self = shift;
-    my ($blocking) = @_;
-
-    $self->get_sock->blocking($blocking?1:0);
-
     my $rc = syswrite (
         $self->get_sock,
         $self->{buffer},
@@ -183,10 +141,10 @@ sub write_blocked {
     my $self = shift;
     my ($data) = @_;
 
-    $self->set_data($data);
+    $self->write($data) and return;
 
     my $finished = 0;
-    $finished = $self->write(1) while not $finished;
+    $finished = $self->write while not $finished;
 
     1;
 }
@@ -195,8 +153,6 @@ sub write_blocked {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Event::RPC::Message - Implementation of Event::RPC network protocol
@@ -214,11 +170,11 @@ network.
 
 =head1 AUTHORS
 
-  Jörn Reder <joern AT zyn.de>
+  Jrn Reder <joern at zyn dot de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
