@@ -1,5 +1,7 @@
+# $Id: Server.pm,v 1.14 2011-03-08 11:50:56 joern Exp $
+
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -9,14 +11,12 @@
 package Event::RPC::Server;
 
 use Event::RPC;
+use Event::RPC::Message;
 use Event::RPC::Connection;
 use Event::RPC::LogConnection;
-use Event::RPC::Message::Negotiate;
 
 use Carp;
 use strict;
-use utf8;
-
 use IO::Socket::INET;
 use Sys::Hostname;
 
@@ -25,7 +25,6 @@ sub get_port                    { shift->{port}                         }
 sub get_name                    { shift->{name}                         }
 sub get_loop                    { shift->{loop}                         }
 sub get_classes                 { shift->{classes}                      }
-sub get_singleton_classes       { shift->{singleton_classes}            }
 sub get_loaded_classes          { shift->{loaded_classes}               }
 sub get_clients_connected       { shift->{clients_connected}            }
 sub get_log_clients_connected   { shift->{log_clients_connected}        }
@@ -38,7 +37,6 @@ sub get_ssl                     { shift->{ssl}                          }
 sub get_ssl_key_file            { shift->{ssl_key_file}                 }
 sub get_ssl_cert_file           { shift->{ssl_cert_file}                }
 sub get_ssl_passwd_cb           { shift->{ssl_passwd_cb}                }
-sub get_ssl_opts                { shift->{ssl_opts}                     }
 sub get_auth_required           { shift->{auth_required}                }
 sub get_auth_passwd_href        { shift->{auth_passwd_href}             }
 sub get_auth_module             { shift->{auth_module}                  }
@@ -47,15 +45,12 @@ sub get_connection_hook         { shift->{connection_hook}              }
 sub get_load_modules            { shift->{load_modules}                 }
 sub get_auto_reload_modules     { shift->{auto_reload_modules}          }
 sub get_active_connection       { shift->{active_connection}            }
-sub get_message_formats         { shift->{message_formats}              }
-sub get_insecure_msg_fmt_ok     { shift->{insecure_msg_fmt_ok}          }
 
 sub set_host                    { shift->{host}                 = $_[1] }
 sub set_port                    { shift->{port}                 = $_[1] }
 sub set_name                    { shift->{name}                 = $_[1] }
 sub set_loop                    { shift->{loop}                 = $_[1] }
 sub set_classes                 { shift->{classes}              = $_[1] }
-sub set_singleton_classes       { shift->{singleton_classes}    = $_[1] }
 sub set_loaded_classes          { shift->{loaded_classes}       = $_[1] }
 sub set_clients_connected       { shift->{clients_connected}    = $_[1] }
 sub set_log_clients_connected   { shift->{log_clients_connected}= $_[1] }
@@ -68,7 +63,6 @@ sub set_ssl                     { shift->{ssl}                  = $_[1] }
 sub set_ssl_key_file            { shift->{ssl_key_file}         = $_[1] }
 sub set_ssl_cert_file           { shift->{ssl_cert_file}        = $_[1] }
 sub set_ssl_passwd_cb           { shift->{ssl_passwd_cb}        = $_[1] }
-sub set_ssl_opts                { shift->{ssl_opts}             = $_[1] }
 sub set_auth_required           { shift->{auth_required}        = $_[1] }
 sub set_auth_passwd_href        { shift->{auth_passwd_href}     = $_[1] }
 sub set_auth_module             { shift->{auth_module}          = $_[1] }
@@ -77,38 +71,23 @@ sub set_connection_hook         { shift->{connection_hook}      = $_[1] }
 sub set_load_modules            { shift->{load_modules}         = $_[1] }
 sub set_auto_reload_modules     { shift->{auto_reload_modules}  = $_[1] }
 sub set_active_connection       { shift->{active_connection}    = $_[1] }
-sub set_message_formats         { shift->{message_formats}      = $_[1] }
-sub set_insecure_msg_fmt_ok     { shift->{insecure_msg_fmt_ok}  = $_[1] }
 
 my $INSTANCE;
 sub instance { $INSTANCE }
 
-sub get_max_packet_size {
-    return Event::RPC::Message->get_max_packet_size;
-}
-
-sub set_max_packet_size {
-    my $class = shift;
-    my ($value) = @_;
-    Event::RPC::Message->set_max_packet_size($value);
-}
-
 sub new {
     my $class = shift;
     my %par = @_;
     my  ($host, $port, $classes, $name, $logger, $start_log_listener) =
     @par{'host','port','classes','name','logger','start_log_listener'};
-    my  ($ssl, $ssl_key_file, $ssl_cert_file, $ssl_passwd_cb, $ssl_opts) =
-    @par{'ssl','ssl_key_file','ssl_cert_file','ssl_passwd_cb','ssl_opts'};
+    my  ($ssl, $ssl_key_file, $ssl_cert_file, $ssl_passwd_cb) =
+    @par{'ssl','ssl_key_file','ssl_cert_file','ssl_passwd_cb'};
     my  ($auth_required, $auth_passwd_href, $auth_module, $loop) =
     @par{'auth_required','auth_passwd_href','auth_module','loop'};
-    my  ($connection_hook, $auto_reload_modules) =
-    @par{'connection_hook','auto_reload_modules'};
-    my  ($load_modules, $message_formats, $insecure_msg_fmt_ok) =
-    @par{'load_modules','message_formats','insecure_msg_fmt_ok'};
+    my  ($connection_hook, $auto_reload_modules, $load_modules) =
+    @par{'connection_hook','auto_reload_modules','load_modules'};
 
     $name ||= "Event-RPC-Server";
-    $insecure_msg_fmt_ok = 1 unless defined $insecure_msg_fmt_ok;
 
     #-- for backwards compatibility 'load_modules' defaults to 1
     if ( !exists $par{load_modules} ) {
@@ -136,7 +115,6 @@ sub new {
         port                    => $port,
         name                    => $name,
         classes                 => $classes,
-        singleton_classes       => {},
         logger                  => $logger,
         start_log_listener      => $start_log_listener,
         loop                    => $loop,
@@ -145,7 +123,6 @@ sub new {
         ssl_key_file            => $ssl_key_file,
         ssl_cert_file           => $ssl_cert_file,
         ssl_passwd_cb           => $ssl_passwd_cb,
-        ssl_opts                => $ssl_opts,
 
         auth_required           => $auth_required,
         auth_passwd_href        => $auth_passwd_href,
@@ -155,9 +132,6 @@ sub new {
         auto_reload_modules     => $auto_reload_modules,
         connection_hook         => $connection_hook,
 
-        message_formats         => $message_formats,
-        insecure_msg_fmt_ok     => $insecure_msg_fmt_ok,
-
         rpc_socket              => undef,
         loaded_classes          => {},
         objects                 => {},
@@ -184,43 +158,6 @@ sub DESTROY {
     1;
 }
 
-sub probe_message_formats {
-    my $class = shift;
-    my ($user_supplied_formats, $insecure_msg_fmt_ok) = @_;
-
-    my $order_lref      = Event::RPC::Message::Negotiate->message_format_order;
-    my $modules_by_name = Event::RPC::Message::Negotiate->known_message_formats;
-
-    my %probe_formats;
-    if ( $user_supplied_formats ) {
-        @probe_formats{@{$user_supplied_formats}} =
-            (1) x @{$user_supplied_formats};
-    }
-    else {
-        %probe_formats = %{$modules_by_name};
-    }
-
-    #-- By default we probe all supported formats, but
-    #-- not Storable. User has to activate this explicitely.
-    if ( not $insecure_msg_fmt_ok ) {
-        delete $probe_formats{STOR};
-    }
-
-    Event::RPC::Message::Negotiate->set_storable_fallback_ok($insecure_msg_fmt_ok);
-
-    my @supported_formats;
-    foreach my $name ( @{$order_lref} ) {
-        next unless $probe_formats{$name};
-
-        my $module = $modules_by_name->{$name};
-        eval "use $module";
-
-        push @supported_formats, $name unless $@;
-    }
-
-    return \@supported_formats;
-}
-
 sub setup_listeners {
     my $self = shift;
 
@@ -241,27 +178,25 @@ sub setup_listeners {
         croak "ssl_key_file not set"  unless $self->get_ssl_key_file;
         croak "ssl_cert_file not set" unless $self->get_ssl_cert_file;
 
-        my $ssl_opts = $self->get_ssl_opts;
-
         $rpc_socket = IO::Socket::SSL->new (
-            Listen          => SOMAXCONN,
-            @LocalHost,
-            LocalPort       => $port,
-            Proto           => 'tcp',
-            ReuseAddr       => 1,
-            SSL_key_file    => $self->get_ssl_key_file,
-            SSL_cert_file   => $self->get_ssl_cert_file,
-            SSL_passwd_cb   => $self->get_ssl_passwd_cb,
-            ($ssl_opts?%{$ssl_opts}:()),
+                Listen          => SOMAXCONN,
+                @LocalHost,
+                LocalPort       => $port,
+                Proto           => 'tcp',
+                ReuseAddr       => 1,
+                SSL_verify_mode => 0x00,
+                SSL_key_file    => $self->get_ssl_key_file,
+                SSL_cert_file   => $self->get_ssl_cert_file,
+                SSL_passwd_cb   => $self->get_ssl_passwd_cb,
         ) or die "can't start SSL RPC listener: $IO::Socket::SSL::ERROR";
     }
     else {
         $rpc_socket = IO::Socket::INET->new (
-            Listen    => SOMAXCONN,
-            @LocalHost,
-            LocalPort => $port,
-            Proto     => 'tcp',
-            ReuseAddr => 1,
+                Listen    => SOMAXCONN,
+                @LocalHost,
+                LocalPort => $port,
+                Proto     => 'tcp',
+                ReuseAddr => 1,
         ) or die "can't start RPC listener: $!";
     }
 
@@ -300,8 +235,6 @@ sub setup_listeners {
         $self->log ("Started log listener on $host:".($port+1));
     }
 
-    $self->determine_singletons;
-
     $self->set_listeners_started(1);
 
     1;
@@ -333,14 +266,6 @@ sub start {
 
     $self->setup_auth_module;
 
-    #-- Filter unsupported message formats
-    $self->set_message_formats(
-        $self->probe_message_formats(
-            $self->get_message_formats,
-            $self->get_insecure_msg_fmt_ok
-        )
-    );
-
     my $loop = $self->get_loop;
 
     $self->log ("Enter main loop using ".ref($loop));
@@ -360,28 +285,6 @@ sub stop {
     1;
 }
 
-sub determine_singletons {
-    my $self = shift;
-
-    my $classes = $self->get_classes;
-    my $singleton_classes = $self->get_singleton_classes;
-
-    foreach my $class ( keys %{$classes} ) {
-        foreach my $method ( keys %{$classes->{$class}} ) {
-            # check for singleton returner
-            if ( $classes->{$class}->{$method} eq '_singleton' ) {
-                # change to constructor
-                $classes->{$class}->{$method} = '_constructor';
-                # track that this class is a singleton
-                $singleton_classes->{$class} = 1;
-                last;
-            }
-        }
-    }
-
-    1;
-}
-
 sub accept_new_client {
     my $self = shift;
     my ($rpc_socket) = @_;
@@ -485,13 +388,6 @@ sub deregister_object {
 
     my $refcount = --$objects->{"$object"}->{refcount};
 
-    my ($class) = split(/=/, $object);
-    if ( $self->get_singleton_classes->{$class} ) {
-        # never deregister singletons
-        $self->log(4, "Skip deregistration of singleton '$object'");
-        return;
-    }
-
     $self->log(5, "Object '$object' deregistered. Refcount=$refcount");
 
     $self->remove_object($object) if $refcount == 0;
@@ -516,8 +412,6 @@ sub print_object_register {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Event::RPC::Server - Simple API for event driven RPC servers
@@ -548,7 +442,6 @@ Event::RPC::Server - Simple API for event driven RPC servers
       ssl_key_file        => "server.key",
       ssl_cert_file       => "server.crt",
       ssl_passwd_cb       => sub { "topsecret" },
-      ssl_opts            => { ... },
 
       auth_required       => 1,
       auth_passwd_href    => { $user => Event::RPC->crypt($user,$pass) },
@@ -560,12 +453,8 @@ Event::RPC::Server - Simple API for event driven RPC servers
       load_modules        => 1,
       auto_reload_modules => 1,
       connection_hook     => sub { ... },
-
-      message_formats     => [qw/ SERL CBOR JSON STOR /],
-      insecure_msg_fmt_ok => 1,
   );
 
-  $server->set_max_packet_size(2*1024*1024*1024);
   $server->start;
 
   # and later from inside your server implementation
@@ -625,7 +514,7 @@ This is a hash ref with the following structure:
     ...
   },
 
-Each class which should be accessible for clients needs to
+Each class which should be accessable for clients needs to
 be listed here at the first level, assigned a hash of methods
 allowed to be called. Event::RPC disuinguishes three types
 of methods by classifying their return value:
@@ -638,12 +527,6 @@ A constructor method creates a new object of the corresponding class
 and returns it. You need to assign the string "_constructor" to
 the method entry to mark a method as a constructor.
 
-=item B<Singleton constructors>
-
-For singleton classes the method which returns the singleton
-instance should be declared with "_singleton". This way the server
-takes care that references get never destroyed on server side.
-
 =item B<Simple methods>
 
 What's simple about these methods is their return value: it's
@@ -724,12 +607,6 @@ password, e.g.
 But note: having the password in plaintext in your program code is
 insecure!
 
-=item B<ssl_opts>
-
-This optional parameter takes a hash reference of options
-passed to IO::Socket::SSL->new(...) to have more control
-over the server SSL listener. 
-
 =back
 
 =head2 AUTHENTICATION OPTIONS
@@ -871,38 +748,6 @@ all necessary Event::RPC listeners:
 
 and manage the main loop stuff on your own.
 
-=head2 MESSAGE FORMAT OPTIONS
-
-Event::RPC supports different CPAN modules for data serialisation,
-named "message formats" here:
-
-  SERL -- Sereal::Encoder, Sereal::Decoder
-  CBOR -- CBOR::XS
-  JSON -- JSON::XS
-  STOR -- Storable
-
-Server and client negotiate automatically which format is
-best to use but you can manipulate this behaviour with the
-following options:
-
-=over 4
-
-=item B<message_formats>
-
-This takes an array of format identifiers from the list
-above. Event::RPC::Server will only use / accept these
-formats.
-
-=item B<insecure_msg_fmt_ok>
-
-The Storable module is known to be insecure. But for
-backward compatibility reasons Event::RPC::Server accepts
-clients which can't offer anything but Storable. You can
-prevent that by setting this option explicitely to 0. It's
-enabled by default.
-
-=back
-
 =head2 MISCELLANEOUS OPTIONS
 
 =over 4
@@ -911,7 +756,7 @@ enabled by default.
 
 By default the network listeners are bound to all interfaces
 in the system. Use the host option to bind to a specific
-interface, e.g. "localhost" if you efficiently want to prevent
+interface, e.g. "localhost" if you efficently want to prevent
 network clients from accessing your server.
 
 =item B<load_modules>
@@ -935,8 +780,6 @@ with two arguments: the Event::RPC::Connection object and
 a string containing either "connect" or "disconnect" depending
 what's currently happening with this connection.
 
-=back
-
 =head1 METHODS
 
 The following methods are publically available:
@@ -984,31 +827,15 @@ representing the connection resp. the client which currently
 requests method invocation. This is undef if no client call
 is active.
 
-=item $rpc_client->B<set_max_packet_size> ( $bytes )
-
-By default Event::RPC does not handle network packages which
-exceed 2 GB in size (was 4 MB with version 1.04 and earlier).
-
-You can change this value using this method at any time,
-but 4 GB is the maximum. An attempt of the server to send a
-bigger packet will be aborted and reported as an exception
-on the client and logged as an error message on the server.
-
-Note: you have to set the same value on client and server side!
-
-=item $rpc_client->B<get_max_packet_size>
-
-Returns the currently active max packet size.
-
 =back
 
 =head1 AUTHORS
 
-  Jörn Reder <joern AT zyn.de>
+  Jrn Reder <joern at zyn dot de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
